ErrorCode

Enum ErrorCode 

pub enum ErrorCode {
Show 26 variants GenericError, NotFound, Exists, Ambiguous, BufSize, User, BareRepo, UnbornBranch, Unmerged, NotFastForward, InvalidSpec, Conflict, Locked, Modified, Auth, Certificate, Applied, Peel, Eof, Invalid, Uncommitted, Directory, MergeConflict, HashsumMismatch, IndexDirty, ApplyFail,
}
An enumeration of possible errors that can happen when working with a git repository.

Variants



GenericError

Generic error



NotFound

Requested object could not be found



Exists

Object exists preventing operation



Ambiguous

More than one object matches



BufSize

Output buffer too short to hold data



User

User-generated error



BareRepo

Operation not allowed on bare repository



UnbornBranch

HEAD refers to branch with no commits



Unmerged

Merge in progress prevented operation



NotFastForward

Reference was not fast-forwardable



InvalidSpec

Name/ref spec was not in a valid format



Conflict

Checkout conflicts prevented operation



Locked

Lock file prevented operation



Modified

Reference value does not match expected



Auth

Authentication error



Certificate

Server certificate is invalid



Applied

Patch/merge has already been applied



Peel

The requested peel operation is not possible



Eof

Unexpected EOF



Invalid

Invalid operation or input



Uncommitted

Uncommitted changes in index prevented operation



Directory

Operation was not valid for a directory



MergeConflict

A merge conflict exists and cannot continue



HashsumMismatch

Hashsum mismatch in object



IndexDirty

Unsaved changes in the index would be overwritten



ApplyFail

Patch application failed